@@ -55,7 +55,7 @@ class ApoJWT():
             - invalid issuer
             - invalid audience (permission)
         """
-        def decorated(fn):
+        def permission_decorated(fn):
             @wraps(fn)
             def wrapper(*args, **kwargs):
                 if self.token_f is None:
@@ -67,13 +67,13 @@ class ApoJWT():
                     jwt.decode(token, self.secret, issuer=self.iss, audience=self.admin_aud, algorithms=[self.algo])
                 return fn(*args, **kwargs)
             return wrapper
-        return decorated
+        return permission_decorated
 
 
     def token_data(self):
         """Retrieves the additional data stored in the JWT payload"""
         token = self.token_f()
-        data = jwt.decode(token, self.secret, issuer=self.iss, algorithms=[self.algo])["data"]
+        data = jwt.decode(token, self.secret, issuer=self.iss, audience="default", algorithms=[self.algo])["data"]
         return data
 
 
